@@ -4,7 +4,6 @@ import getpass
 import docker.errors
 from cowait.tasks import TaskDefinition
 from cowait.engine.errors import TaskCreationError, ProviderError
-from cowait.utils import parse_task_image_name
 from cowait.tasks.messages import TASK_INIT, TASK_STATUS, TASK_FAIL, TASK_RETURN, TASK_LOG
 from ..config import Config
 from ..context import Context
@@ -15,10 +14,15 @@ from .build import build as build_cmd
 from sty import fg, rs
 
 
+class TaskFailedError(RuntimeError):
+    pass
+
+
 def run(
     config: Config,
     task: str, *,
     name: str = None,
+    image: str = None,
     inputs: dict = {},
     env: dict = {},
     ports: dict = {},
@@ -43,7 +47,6 @@ def run(
 
         # figure out image name
         remote_image = True
-        image, task = parse_task_image_name(task, None)
         if image is None:
             if build:
                 build_cmd(config, quiet=quiet or raw)
@@ -55,11 +58,12 @@ def run(
 
         # if we are using the image of the current context, automatically mount the working directory
         # todo: add an option to disable this
-        if not remote_image or image == 'cowait/notebook':
+        if not remote_image:
             volumes['/var/task'] = {
                 'bind': {
                     'src': context.root_path,
                     'mode': 'rw',
+                    'inherit': 'same-image',
                 },
             }
 
@@ -119,12 +123,18 @@ def run(
 
     except docker.errors.NotFound as e:
         logger.print_exception(f'Docker Error: {e.explanation}')
+        sys.exit(1)
 
     except ProviderError as e:
         logger.print_exception(f'Provider Error: {e}')
+        sys.exit(1)
 
     except TaskCreationError as e:
         logger.print_exception(f'Error creating task: {e}')
+        sys.exit(1)
+
+    except TaskFailedError:
+        sys.exit(1)
 
 
 class RunLogger(Logger):
@@ -219,6 +229,8 @@ class RunLogger(Logger):
         self.print_time(ts)
         self.print_id(id)
         self.println(f'{fg.red} ! {rs.all}ERROR: {error}')
+        if id == self.id:
+            raise TaskFailedError(error)
 
     def on_return(self, id: str, result: any, ts: str = None, **msg):
         self.print_time(ts)
