@@ -1,3 +1,4 @@
+import json
 
 
 class StoppedError(RuntimeError):
@@ -5,6 +6,12 @@ class StoppedError(RuntimeError):
         super().__init__('Exited')
         self.result = result
 
+    def _render_traceback_(self):
+        try:
+            return ['Returned with result:'] + json.dumps(self.result, indent=2).split('\n')
+        except TypeError:
+            return ['Returned with result:', str(self.result)]
+
 
 class TaskError(RuntimeError):
     """
